@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
@@ -53,11 +55,15 @@ __all__ = (
     "DeleteInsightRulesInputRequestTypeDef",
     "DeleteInsightRulesOutputTypeDef",
     "DeleteMetricStreamInputRequestTypeDef",
-    "DescribeAlarmHistoryInputAlarmTypeDef",
+    "DescribeAlarmHistoryInputAlarmDescribeHistoryTypeDef",
+    "DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef",
     "DescribeAlarmHistoryInputRequestTypeDef",
     "DescribeAlarmHistoryOutputTypeDef",
     "DescribeAlarmsForMetricInputRequestTypeDef",
     "DescribeAlarmsForMetricOutputTypeDef",
+    "DescribeAlarmsInputAlarmExistsWaitTypeDef",
+    "DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef",
+    "DescribeAlarmsInputDescribeAlarmsPaginateTypeDef",
     "DescribeAlarmsInputRequestTypeDef",
     "DescribeAlarmsOutputTypeDef",
     "DescribeAnomalyDetectorsInputRequestTypeDef",
@@ -76,9 +82,10 @@ __all__ = (
     "GetDashboardOutputTypeDef",
     "GetInsightRuleReportInputRequestTypeDef",
     "GetInsightRuleReportOutputTypeDef",
+    "GetMetricDataInputGetMetricDataPaginateTypeDef",
     "GetMetricDataInputRequestTypeDef",
     "GetMetricDataOutputTypeDef",
-    "GetMetricStatisticsInputMetricTypeDef",
+    "GetMetricStatisticsInputMetricGetStatisticsTypeDef",
     "GetMetricStatisticsInputRequestTypeDef",
     "GetMetricStatisticsOutputTypeDef",
     "GetMetricStreamInputRequestTypeDef",
@@ -90,10 +97,12 @@ __all__ = (
     "InsightRuleMetricDatapointTypeDef",
     "InsightRuleTypeDef",
     "LabelOptionsTypeDef",
+    "ListDashboardsInputListDashboardsPaginateTypeDef",
     "ListDashboardsInputRequestTypeDef",
     "ListDashboardsOutputTypeDef",
     "ListMetricStreamsInputRequestTypeDef",
     "ListMetricStreamsOutputTypeDef",
+    "ListMetricsInputListMetricsPaginateTypeDef",
     "ListMetricsInputRequestTypeDef",
     "ListMetricsOutputTypeDef",
     "ListTagsForResourceInputRequestTypeDef",
@@ -115,7 +124,7 @@ __all__ = (
     "PutDashboardInputRequestTypeDef",
     "PutDashboardOutputTypeDef",
     "PutInsightRuleInputRequestTypeDef",
-    "PutMetricAlarmInputMetricTypeDef",
+    "PutMetricAlarmInputMetricPutAlarmTypeDef",
     "PutMetricAlarmInputRequestTypeDef",
     "PutMetricDataInputRequestTypeDef",
     "PutMetricStreamInputRequestTypeDef",
@@ -124,7 +133,7 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "ServiceResourceAlarmRequestTypeDef",
     "ServiceResourceMetricRequestTypeDef",
-    "SetAlarmStateInputAlarmTypeDef",
+    "SetAlarmStateInputAlarmSetStateTypeDef",
     "SetAlarmStateInputRequestTypeDef",
     "SingleMetricAnomalyDetectorTypeDef",
     "StartMetricStreamsInputRequestTypeDef",
@@ -277,8 +286,8 @@ DeleteMetricStreamInputRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAlarmHistoryInputAlarmTypeDef = TypedDict(
-    "DescribeAlarmHistoryInputAlarmTypeDef",
+DescribeAlarmHistoryInputAlarmDescribeHistoryTypeDef = TypedDict(
+    "DescribeAlarmHistoryInputAlarmDescribeHistoryTypeDef",
     {
         "AlarmTypes": Sequence[AlarmTypeType],
         "HistoryItemType": HistoryItemTypeType,
@@ -291,6 +300,20 @@ DescribeAlarmHistoryInputAlarmTypeDef = TypedDict(
     total=False,
 )
 
+DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef = TypedDict(
+    "DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef",
+    {
+        "AlarmName": str,
+        "AlarmTypes": Sequence[AlarmTypeType],
+        "HistoryItemType": HistoryItemTypeType,
+        "StartDate": Union[datetime, str],
+        "EndDate": Union[datetime, str],
+        "ScanBy": ScanByType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeAlarmHistoryInputRequestTypeDef = TypedDict(
     "DescribeAlarmHistoryInputRequestTypeDef",
     {
@@ -350,6 +373,55 @@ DescribeAlarmsForMetricOutputTypeDef = TypedDict(
     },
 )
 
+DescribeAlarmsInputAlarmExistsWaitTypeDef = TypedDict(
+    "DescribeAlarmsInputAlarmExistsWaitTypeDef",
+    {
+        "AlarmNames": Sequence[str],
+        "AlarmNamePrefix": str,
+        "AlarmTypes": Sequence[AlarmTypeType],
+        "ChildrenOfAlarmName": str,
+        "ParentsOfAlarmName": str,
+        "StateValue": StateValueType,
+        "ActionPrefix": str,
+        "MaxRecords": int,
+        "NextToken": str,
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef = TypedDict(
+    "DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef",
+    {
+        "AlarmNames": Sequence[str],
+        "AlarmNamePrefix": str,
+        "AlarmTypes": Sequence[AlarmTypeType],
+        "ChildrenOfAlarmName": str,
+        "ParentsOfAlarmName": str,
+        "StateValue": StateValueType,
+        "ActionPrefix": str,
+        "MaxRecords": int,
+        "NextToken": str,
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+DescribeAlarmsInputDescribeAlarmsPaginateTypeDef = TypedDict(
+    "DescribeAlarmsInputDescribeAlarmsPaginateTypeDef",
+    {
+        "AlarmNames": Sequence[str],
+        "AlarmNamePrefix": str,
+        "AlarmTypes": Sequence[AlarmTypeType],
+        "ChildrenOfAlarmName": str,
+        "ParentsOfAlarmName": str,
+        "StateValue": StateValueType,
+        "ActionPrefix": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeAlarmsInputRequestTypeDef = TypedDict(
     "DescribeAlarmsInputRequestTypeDef",
     {
@@ -544,6 +616,32 @@ GetInsightRuleReportOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredGetMetricDataInputGetMetricDataPaginateTypeDef = TypedDict(
+    "_RequiredGetMetricDataInputGetMetricDataPaginateTypeDef",
+    {
+        "MetricDataQueries": Sequence["MetricDataQueryTypeDef"],
+        "StartTime": Union[datetime, str],
+        "EndTime": Union[datetime, str],
+    },
+)
+_OptionalGetMetricDataInputGetMetricDataPaginateTypeDef = TypedDict(
+    "_OptionalGetMetricDataInputGetMetricDataPaginateTypeDef",
+    {
+        "ScanBy": ScanByType,
+        "LabelOptions": "LabelOptionsTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class GetMetricDataInputGetMetricDataPaginateTypeDef(
+    _RequiredGetMetricDataInputGetMetricDataPaginateTypeDef,
+    _OptionalGetMetricDataInputGetMetricDataPaginateTypeDef,
+):
+    pass
+
+
 _RequiredGetMetricDataInputRequestTypeDef = TypedDict(
     "_RequiredGetMetricDataInputRequestTypeDef",
     {
@@ -580,16 +678,16 @@ GetMetricDataOutputTypeDef = TypedDict(
     },
 )
 
-_RequiredGetMetricStatisticsInputMetricTypeDef = TypedDict(
-    "_RequiredGetMetricStatisticsInputMetricTypeDef",
+_RequiredGetMetricStatisticsInputMetricGetStatisticsTypeDef = TypedDict(
+    "_RequiredGetMetricStatisticsInputMetricGetStatisticsTypeDef",
     {
         "StartTime": Union[datetime, str],
         "EndTime": Union[datetime, str],
         "Period": int,
     },
 )
-_OptionalGetMetricStatisticsInputMetricTypeDef = TypedDict(
-    "_OptionalGetMetricStatisticsInputMetricTypeDef",
+_OptionalGetMetricStatisticsInputMetricGetStatisticsTypeDef = TypedDict(
+    "_OptionalGetMetricStatisticsInputMetricGetStatisticsTypeDef",
     {
         "Dimensions": Sequence["DimensionTypeDef"],
         "Statistics": Sequence[StatisticType],
@@ -600,8 +698,9 @@ _OptionalGetMetricStatisticsInputMetricTypeDef = TypedDict(
 )
 
 
-class GetMetricStatisticsInputMetricTypeDef(
-    _RequiredGetMetricStatisticsInputMetricTypeDef, _OptionalGetMetricStatisticsInputMetricTypeDef
+class GetMetricStatisticsInputMetricGetStatisticsTypeDef(
+    _RequiredGetMetricStatisticsInputMetricGetStatisticsTypeDef,
+    _OptionalGetMetricStatisticsInputMetricGetStatisticsTypeDef,
 ):
     pass
 
@@ -759,6 +858,15 @@ LabelOptionsTypeDef = TypedDict(
     total=False,
 )
 
+ListDashboardsInputListDashboardsPaginateTypeDef = TypedDict(
+    "ListDashboardsInputListDashboardsPaginateTypeDef",
+    {
+        "DashboardNamePrefix": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDashboardsInputRequestTypeDef = TypedDict(
     "ListDashboardsInputRequestTypeDef",
     {
@@ -795,6 +903,18 @@ ListMetricStreamsOutputTypeDef = TypedDict(
     },
 )
 
+ListMetricsInputListMetricsPaginateTypeDef = TypedDict(
+    "ListMetricsInputListMetricsPaginateTypeDef",
+    {
+        "Namespace": str,
+        "MetricName": str,
+        "Dimensions": Sequence["DimensionFilterTypeDef"],
+        "RecentlyActive": Literal["PT3H"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListMetricsInputRequestTypeDef = TypedDict(
     "ListMetricsInputRequestTypeDef",
     {
@@ -1099,16 +1219,16 @@ class PutInsightRuleInputRequestTypeDef(
     pass
 
 
-_RequiredPutMetricAlarmInputMetricTypeDef = TypedDict(
-    "_RequiredPutMetricAlarmInputMetricTypeDef",
+_RequiredPutMetricAlarmInputMetricPutAlarmTypeDef = TypedDict(
+    "_RequiredPutMetricAlarmInputMetricPutAlarmTypeDef",
     {
         "AlarmName": str,
         "EvaluationPeriods": int,
         "ComparisonOperator": ComparisonOperatorType,
     },
 )
-_OptionalPutMetricAlarmInputMetricTypeDef = TypedDict(
-    "_OptionalPutMetricAlarmInputMetricTypeDef",
+_OptionalPutMetricAlarmInputMetricPutAlarmTypeDef = TypedDict(
+    "_OptionalPutMetricAlarmInputMetricPutAlarmTypeDef",
     {
         "AlarmDescription": str,
         "ActionsEnabled": bool,
@@ -1132,8 +1252,9 @@ _OptionalPutMetricAlarmInputMetricTypeDef = TypedDict(
 )
 
 
-class PutMetricAlarmInputMetricTypeDef(
-    _RequiredPutMetricAlarmInputMetricTypeDef, _OptionalPutMetricAlarmInputMetricTypeDef
+class PutMetricAlarmInputMetricPutAlarmTypeDef(
+    _RequiredPutMetricAlarmInputMetricPutAlarmTypeDef,
+    _OptionalPutMetricAlarmInputMetricPutAlarmTypeDef,
 ):
     pass
 
@@ -1255,15 +1376,15 @@ ServiceResourceMetricRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredSetAlarmStateInputAlarmTypeDef = TypedDict(
-    "_RequiredSetAlarmStateInputAlarmTypeDef",
+_RequiredSetAlarmStateInputAlarmSetStateTypeDef = TypedDict(
+    "_RequiredSetAlarmStateInputAlarmSetStateTypeDef",
     {
         "StateValue": StateValueType,
         "StateReason": str,
     },
 )
-_OptionalSetAlarmStateInputAlarmTypeDef = TypedDict(
-    "_OptionalSetAlarmStateInputAlarmTypeDef",
+_OptionalSetAlarmStateInputAlarmSetStateTypeDef = TypedDict(
+    "_OptionalSetAlarmStateInputAlarmSetStateTypeDef",
     {
         "StateReasonData": str,
     },
@@ -1271,8 +1392,8 @@ _OptionalSetAlarmStateInputAlarmTypeDef = TypedDict(
 )
 
 
-class SetAlarmStateInputAlarmTypeDef(
-    _RequiredSetAlarmStateInputAlarmTypeDef, _OptionalSetAlarmStateInputAlarmTypeDef
+class SetAlarmStateInputAlarmSetStateTypeDef(
+    _RequiredSetAlarmStateInputAlarmSetStateTypeDef, _OptionalSetAlarmStateInputAlarmSetStateTypeDef
 ):
     pass
 
